import { ServerResponse } from '../../common-ts/lib/type/server-types';
import { BlockHeaderResponse, GetInfoResponse } from './type/blockchain-types';
import { Accept, Announcement, Attestment, Offer, Sign } from './type/core-types';
import { AddressInfo, Balances, DLCContract, DLCWalletAccounting, FundedAddress, Outpoint, UTXO, WalletInfo } from './type/wallet-types';
export * from '../../common-ts/lib/index';
/** Blockchain functions */
export declare function GetBlockCount(): Promise<ServerResponse<number>>;
export declare function GetFilterCount(): Promise<ServerResponse<number>>;
export declare function GetFilterHeaderCount(): Promise<ServerResponse<number>>;
export declare function GetBlockHeader(sha256hash: string): Promise<ServerResponse<BlockHeaderResponse>>;
export declare function GetInfo(): Promise<ServerResponse<GetInfoResponse>>;
/** Network message functions */
export declare function GetPeers(): Promise<ServerResponse<string>>;
export declare function Stop(): Promise<ServerResponse<string>>;
/** Specific Server message functions */
export declare function IsEmpty(): Promise<ServerResponse<boolean>>;
export declare function WalletInfo(): Promise<ServerResponse<WalletInfo>>;
export declare function GetBalance(inSats: boolean): Promise<ServerResponse<string>>;
export declare function GetConfirmedBalance(inSats: boolean): Promise<ServerResponse<string>>;
export declare function GetUnconfirmedBalance(inSats: boolean): Promise<ServerResponse<string>>;
export declare function GetBalances(inSats: boolean): Promise<ServerResponse<Balances>>;
export declare function GetNewAddress(label?: string): Promise<ServerResponse<string>>;
export declare function GetTransaction(sha256hash: string): Promise<ServerResponse<string>>;
export declare function LockUnspent(unlock: boolean, outPoints: any[]): Promise<ServerResponse<boolean>>;
export declare function LabelAddress(address: string, label: string): Promise<ServerResponse<string>>;
export declare function GetAddressLabels(address: string): Promise<ServerResponse<string[]>>;
export declare function DropAddressLabels(address: string): Promise<ServerResponse<string>>;
/** DLC Message Functions */
export declare function GetDLCHostAddress(): Promise<ServerResponse<string>>;
export declare function CreateContractInfo(announcementTLV: string, totalCollateral: number, payoutsVal: any): Promise<string | ServerResponse<string>>;
export declare function GetDLCs(): Promise<ServerResponse<DLCContract[]>>;
export declare function GetDLC(sha256hash: string): Promise<ServerResponse<DLCContract>>;
export declare function CancelDLC(sha256hash: string): Promise<ServerResponse<string>>;
export declare function CreateDLCOffer(contractInfoTLV: string, collateral: number, feeRate: number, locktime: number, refundLT: number): Promise<ServerResponse<string>>;
export declare function AcceptDLCOffer(offerHex: string): Promise<ServerResponse<string>>;
export declare function AcceptDLCOfferFromFile(path: string, destination?: string): Promise<ServerResponse<unknown>>;
export declare function SignDLC(acceptHex: string): Promise<ServerResponse<unknown>>;
export declare function SignDLCFromFile(path: string, destination?: string): Promise<ServerResponse<unknown>>;
export declare function AddDLCSigs(sigsHex: string): Promise<ServerResponse<unknown>>;
export declare function AddDLCSigsFromFile(path: string, destination?: string): Promise<ServerResponse<unknown>>;
export declare function AddDLCSigsAndBroadcast(sigsHex: string): Promise<ServerResponse<string>>;
export declare function AddDLCSigsAndBroadcastFromFile(path: string, destination?: string): Promise<ServerResponse<unknown>>;
export declare function GetDLCFundingTx(contractIdHex: string): Promise<ServerResponse<unknown>>;
export declare function BroadcastDLCFundingTx(contractIdHex: string): Promise<ServerResponse<unknown>>;
export declare function ExecuteDLC(contractIdHex: string, oracleSigs: string[], noBroadcast: boolean): Promise<ServerResponse<string>>;
export declare function ExecuteDLCRefund(contractIdHex: string, noBroadcast: boolean): Promise<ServerResponse<string>>;
export declare function SendToAddress(address: string, bitcoins: number, satsPerVByte: number, noBroadcast: boolean): Promise<ServerResponse<string>>;
export declare function SendFromOutpoints(outPoints: Outpoint[], bitcoins: number, satsPerVByte: number): Promise<ServerResponse<string>>;
export declare function SweepWallet(address: string, satsPerVByte: number): Promise<ServerResponse<string>>;
export declare function SendWithAlgo(address: string, bitcoins: number, satsPerVByte: number, algo: string): Promise<ServerResponse<unknown>>;
export declare function SignPSBT(hexOrBase64: string): Promise<ServerResponse<unknown>>;
export declare function OpReturnCommit(message: string, hashMessage: boolean, satsPerVByte: number): Promise<ServerResponse<unknown>>;
export declare function BumpFeeRBF(sha256hash: string, satsPerVByte: number): Promise<ServerResponse<unknown>>;
export declare function BumpFeeCPFP(sha256hash: string, satsPerVByte: number): Promise<ServerResponse<unknown>>;
export declare function Rescan(batchSize: number | null, start: number | null, end: number | null, force: boolean, ignoreCreationTime: boolean): Promise<ServerResponse<string>>;
export declare function GetUTXOs(): Promise<ServerResponse<UTXO[]>>;
export declare function ListReservedUTXOs(): Promise<ServerResponse<UTXO[]>>;
export declare function GetAddresses(): Promise<ServerResponse<string[]>>;
export declare function GetSpentAddresses(): Promise<ServerResponse<string[]>>;
export declare function GetFundedAddresses(): Promise<ServerResponse<FundedAddress[]>>;
export declare function GetUnusedAddresses(): Promise<ServerResponse<string[]>>;
export declare function GetAccounts(): Promise<ServerResponse<string[]>>;
export declare function GetAddressInfo(address: string): Promise<ServerResponse<AddressInfo>>;
export declare function CreateNewAccount(): Promise<ServerResponse<unknown>>;
export declare function ImportSeed(walletName: string, mnemonic: string, passphrase?: string): Promise<ServerResponse<unknown>>;
export declare function ImportXprv(walletName: string, mnemonic: string, passphrase?: string): Promise<ServerResponse<unknown>>;
export declare function SendRawTransaction(hex: string): Promise<ServerResponse<string>>;
export declare function EstimateFee(): Promise<ServerResponse<number>>;
export declare function GetDLCWalletAccounting(): Promise<ServerResponse<DLCWalletAccounting>>;
export declare function BackupWallet(path: string): Promise<ServerResponse<string>>;
/** Core Route Functions */
export declare function FinalizePSBT(): Promise<ServerResponse<unknown>>;
export declare function ExtractFromPSBT(): Promise<ServerResponse<unknown>>;
export declare function ConvertToPSBT(): Promise<ServerResponse<unknown>>;
export declare function CombinePSBT(): Promise<ServerResponse<unknown>>;
export declare function JoinPSBTs(): Promise<ServerResponse<unknown>>;
export declare function DecodePSBT(): Promise<ServerResponse<unknown>>;
export declare function DecodeRawTransaction(): Promise<ServerResponse<unknown>>;
export declare function AnalyzePSBT(): Promise<ServerResponse<unknown>>;
export declare function DecodeSign(signedHex: string): Promise<ServerResponse<Sign>>;
export declare function DecodeAccept(acceptHex: string): Promise<ServerResponse<Accept>>;
export declare function DecodeOffer(offerHex: string): Promise<ServerResponse<Offer>>;
export declare function DecodeContractInfo(contractInfoHex: string): Promise<ServerResponse<unknown>>;
export declare function DecodeAnnouncement(announcementHex: string): Promise<ServerResponse<Announcement>>;
export declare function DecodeAttestments(attestmentHex: string): Promise<ServerResponse<Attestment>>;
export declare function CreateMultiSig(): Promise<ServerResponse<unknown>>;
